package main

import (
	"github.com/adlio/trello"
	_ "github.com/adlio/trello"
	"github.com/rs/zerolog"
	"github.com/rs/zerolog/log"
	"github.com/urfave/cli/v2"
	_ "github.com/urfave/cli/v2"
	"os"
)

func getTrelloClient() *trello.Client {
	client := trello.NewClient(trelloAPIKey, trelloAPIToken)
	return client
}

func main() {
	log.Logger = log.Output(zerolog.ConsoleWriter{Out: os.Stderr})

	app := &cli.App{
		Commands: []*cli.Command{
			{
				Name:    "reset-daily-tasks",
				Aliases: []string{"rd"},
				Usage:   "Reset all Task with a label \"Daily\" back to the list \"ToDo\"",
				Action:  resetDailyTasks,
			},
			{
				Name:    "remove-done-cards",
				Aliases: []string{"rm"},
				Usage:   "Reset all Cards in the list \"Done\"",
				Action:  removeDoneCArds,
			},
			{
				Name: "move-backlog-card-with-date",
				//Aliases: []string{"rm"},
				Usage:  "Move all cards from \"Backlog\" to \"ToDo\" where the End Date is in the past and remove the duedate",
				Action: moveBacklogCardWithDate,
			},
			{
				Name:   "unassign-cards",
				Usage:  "Assign all cards without member to current users",
				Action: unassignCards,
			},
			{
				Name:   "daily-habit-image",
				Usage:  "Daily habit image",
				Action: dailyHabitImage,
			},
		},
	}

	if err := app.Run(os.Args); err != nil {
		log.Fatal().Err(err).Msg("Error running app")
	}
}
